package com.cmvr.aima.service;

import java.util.List;
import com.cmvr.aima.domain.AimaTestCase;
import com.cmvr.aima.domain.vo.AimaTestCaseVo;

/**
 * 爱玛测试用例Service接口
 * 
 * @author cmvr-iot
 * @since 2026-06-22
 */
public interface IAimaTestCaseService {
    /**
     * 查询爱玛测试用例
     * 
     * @param id 爱玛测试用例主键
     * @return 爱玛测试用例
     */
    AimaTestCase selectAimaTestCaseById(String id);

    /**
     * 查询爱玛测试用例列表
     * 
     * @param aimaTestCase 爱玛测试用例
     * @return 爱玛测试用例集合
     */
    List<AimaTestCase> selectAimaTestCaseList(AimaTestCase aimaTestCase);

    /**
     * 查询爱玛测试用例视图列表（包含关联信息）
     * 
     * @param aimaTestCase 爱玛测试用例
     * @return 爱玛测试用例视图集合
     */
    List<AimaTestCaseVo> selectAimaTestCaseVoList(AimaTestCase aimaTestCase);

    /**
     * 新增爱玛测试用例
     * 
     * @param aimaTestCase 爱玛测试用例
     * @return 结果
     */
    int insertAimaTestCase(AimaTestCase aimaTestCase);

    /**
     * 修改爱玛测试用例
     * 
     * @param aimaTestCase 爱玛测试用例
     * @return 结果
     */
    int updateAimaTestCase(AimaTestCase aimaTestCase);

    /**
     * 批量删除爱玛测试用例
     * 
     * @param ids 需要删除的爱玛测试用例主键集合
     * @return 结果
     */
    int deleteAimaTestCaseByIds(String[] ids);

    /**
     * 删除爱玛测试用例信息
     * 
     * @param id 爱玛测试用例主键
     * @return 结果
     */
    int deleteAimaTestCaseById(String id);
}
